@@ -1,5 +1,5 @@
  /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-single.c,v 1.42 2006/01/29 21:09:52 crispin Exp $
+ *  $Id: ephy-embed-single.c,v 1.44 2006/09/13 11:34:13 chpe Exp $
  */
 
 #include "config.h"
@@ -34,7 +34,7 @@ ephy_embed_single_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyEmbedSingleIface),
 			ephy_embed_single_iface_init,
