@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.c,v 1.70 2005/12/07 17:54:56 chpe Exp $
+ *  $Id: ephy-embed.c,v 1.74 2006/10/22 17:07:50 jframeau Exp $
  */
 
 #include "config.h"
@@ -36,7 +36,7 @@ ephy_embed_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyEmbedIface),
 			ephy_embed_base_init,
@@ -386,6 +386,22 @@ ephy_embed_base_init (gpointer g_class)
 			      ephy_marshal_BOOLEAN__VOID,
 			      G_TYPE_BOOLEAN,
 			      0);
+/**
+ * EphyEmbed::content-blocked:
+ * @embed:
+ * @uri: blocked URI 
+ *
+ * The ::content-blocked signal is emitted when an url has been blocked.
+ **/
+		g_signal_new ("content-blocked",
+			      EPHY_TYPE_EMBED,
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (EphyEmbedIface, content_blocked),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__STRING,
+			      G_TYPE_NONE,
+			      1,
+			      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
 
 		initialized = TRUE;
 	}
@@ -406,6 +422,25 @@ ephy_embed_load_url (EphyEmbed *embed,
 	iface->load_url (embed, url);
 }
 
+/**
+ * ephy_embed_load:
+ * @embed: an #EphyEmbed
+ * @url: an URL
+ * @flags: flags modifying load behaviour
+ * @previous_embed: the referrer embed or %NULL
+ *
+ * Loads a new web page in @embed.
+ **/
+void
+ephy_embed_load (EphyEmbed *embed,
+		 const char *url,
+		 EphyEmbedLoadFlags flags,
+		 EphyEmbed *referring_embed)
+{
+	EphyEmbedIface *iface = EPHY_EMBED_GET_IFACE (embed);
+	iface->load (embed, url, flags, referring_embed);
+}
+
 /**
  * ephy_embed_stop_load:
  * @embed: an #EphyEmbed
