@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.h,v 1.62 2005/12/07 17:54:56 chpe Exp $
+ *  $Id: ephy-embed.h,v 1.65 2006/10/22 17:07:51 jframeau Exp $
  */
 
 #ifndef EPHY_EMBED_H
@@ -63,6 +63,12 @@ typedef enum
 	EPHY_EMBED_CHROME_BOOKMARKSBAR	= 1 << 3
 } EphyEmbedChrome;
 
+typedef enum
+{
+	EPHY_EMBED_LOAD_FLAGS_NONE			= 1 << 0,
+	EPHY_EMBED_LOAD_FLAGS_ALLOW_THIRD_PARTY_FIXUP 	= 1 << 1,
+} EphyEmbedLoadFlags;
+
 #define EPHY_EMBED_CHROME_ALL (EPHY_EMBED_CHROME_MENUBAR |	\
 			       EPHY_EMBED_CHROME_TOOLBAR |	\
 			       EPHY_EMBED_CHROME_STATUSBAR |	\
@@ -142,6 +148,8 @@ struct _EphyEmbedIface
 					 float new_zoom);
 	void	 (* content_change)	(EphyEmbed *embed,
 					 const char *uri);
+	void	 (* content_blocked)	(EphyEmbed *embed,
+					 const char *uri);
 	gboolean (* modal_alert)	(EphyEmbed *embed);
 	void	 (* modal_alert_closed)	(EphyEmbed *embed);
 	void	 (* document_type)	(EphyEmbed *embed,
@@ -155,6 +163,10 @@ struct _EphyEmbedIface
 	/* Methods  */
 	void		   (* load_url)			(EphyEmbed *embed,
 							 const char *url);
+	void		   (* load)			(EphyEmbed *embed,
+							 const char *url,
+							 EphyEmbedLoadFlags flags,
+							 EphyEmbed *referring_embed);
 	void		   (* stop_load)		(EphyEmbed *embed);
 	void		   (* reload)			(EphyEmbed *embed,
 							 gboolean force);
@@ -230,6 +242,10 @@ GType		  ephy_embed_get_type			(void);
 /* Base */
 void		  ephy_embed_load_url			(EphyEmbed *embed,
 							 const char *url);
+void		  ephy_embed_load			(EphyEmbed *embed,
+							 const char *url,
+							 EphyEmbedLoadFlags flags,
+							 EphyEmbed *referring_embed);
 
 void		  ephy_embed_stop_load			(EphyEmbed *embed);
 
