@@ -1,6 +1,6 @@
 /* -*- Mode: C++; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyContentPolicy.cpp,v 1.24 2006/05/10 18:07:00 chpe Exp $
+ *  $Id: EphyContentPolicy.cpp,v 1.26 2006/09/16 21:20:36 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -25,12 +25,15 @@
 #include <nsStringAPI.h>
 
 #include <nsCOMPtr.h>
+#include <nsICategoryManager.h>
 #include <nsIDOMAbstractView.h>
 #include <nsIDOMDocument.h>
 #include <nsIDOMDocumentView.h>
 #include <nsIDOMNode.h>
 #include <nsIDOMWindow.h>
 #include <nsIURI.h>
+#include <nsServiceManagerUtils.h>
+#include <nsXPCOMCID.h>
 
 #include "eel-gconf-extensions.h"
 #include "ephy-adblock-manager.h"
@@ -197,3 +200,44 @@ EphyContentPolicy::ShouldProcess(PRUint32 aContentType,
 	*aDecision = nsIContentPolicy::ACCEPT;
 	return NS_OK;
 }
+
+
+/* static */ NS_METHOD
+EphyContentPolicy::Register (nsIComponentManager* aComponentManager,
+			     nsIFile* aPath,
+			     const char* aRegistryLocation,
+			     const char* aComponentType,
+			     const nsModuleComponentInfo* aInfo)
+{
+  nsresult rv;
+  nsCOMPtr<nsICategoryManager> catMan (do_GetService(NS_CATEGORYMANAGER_CONTRACTID, &rv));
+  NS_ENSURE_SUCCESS (rv, rv);
+
+  rv = catMan->AddCategoryEntry ("content-policy",
+				 EPHY_CONTENT_POLICY_CONTRACTID,
+				 EPHY_CONTENT_POLICY_CONTRACTID,
+				 PR_FALSE /* don't persist */,
+				 PR_TRUE /* replace */,
+				 nsnull);
+  NS_ENSURE_SUCCESS (rv, rv);
+
+  return rv;
+}
+
+/* static */ NS_METHOD
+EphyContentPolicy::Unregister (nsIComponentManager* aComponentManager,
+			       nsIFile* aPath,
+			       const char* aRegistryLocation,
+			       const nsModuleComponentInfo* aInfo)
+{
+  nsresult rv;
+  nsCOMPtr<nsICategoryManager> catMan (do_GetService(NS_CATEGORYMANAGER_CONTRACTID, &rv));
+  NS_ENSURE_SUCCESS (rv, rv);
+
+  rv = catMan->DeleteCategoryEntry ("content-policy",
+				    EPHY_CONTENT_POLICY_CONTRACTID,
+				    PR_FALSE /* don't persist */);
+  NS_ENSURE_SUCCESS (rv, rv);
+
+  return rv;
+}
