@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2006 Christian Persch
+ *  Copyright © 2006 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GeckoPrintService.cpp,v 1.4 2006/08/21 18:20:56 chpe Exp $
+ *  $Id: GeckoPrintService.cpp,v 1.6 2006/11/04 17:35:19 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -534,8 +534,9 @@ GeckoPrintService::TranslateSettings (GtkPrintSettings *aGtkSettings,
         if (numRanges > 0) {
           /* FIXME: We can only support one range, ignore more ranges or raise error? */
           aSettings->SetPrintRange (nsIPrintSettings::kRangeSpecifiedPageRange);
-          aSettings->SetStartPageRange (pageRanges[0].start);
-	  aSettings->SetEndPageRange (pageRanges[1].end);
+	  /* Gecko page numbers start at 1, while gtk page numbers start at 0 */
+          aSettings->SetStartPageRange (pageRanges[0].start + 1);
+	  aSettings->SetEndPageRange (pageRanges[0].end + 1);
 
 	  g_free (pageRanges);
         }
