@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000, 2001, 2002 Marco Pesenti Gritti
+ *  Copyright © 2000, 2001, 2002 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,16 +15,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-download.h,v 1.4 2004/03/01 00:58:50 marco Exp $
+ *  $Id: mozilla-download.h,v 1.7 2006/09/13 11:34:15 chpe Exp $
  */
 
 #ifndef MOZILLA_DOWNLOAD_H
 #define MOZILLA_DOWNLOAD_H
 
-#include "MozDownload.h"
-
-#include <glib-object.h>
 #include <glib.h>
+#include <glib-object.h>
+
+#include "ephy-download.h"
 
 G_BEGIN_DECLS
 
@@ -35,17 +35,19 @@ G_BEGIN_DECLS
 #define MOZILLA_IS_DOWNLOAD_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), MOZILLA_TYPE_DOWNLOAD))
 #define MOZILLA_DOWNLOAD_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), MOZILLA_TYPE_DOWNLOAD, MozillaDownloadClass))
 
-typedef struct MozillaDownloadClass MozillaDownloadClass;
-typedef struct MozillaDownload MozillaDownload;
-typedef struct MozillaDownloadPrivate MozillaDownloadPrivate;
+typedef struct _MozillaDownloadClass	MozillaDownloadClass;
+typedef struct _MozillaDownload		MozillaDownload;
+typedef struct _MozillaDownloadPrivate	MozillaDownloadPrivate;
 
-struct MozillaDownload
+class MozDownload;
+
+struct _MozillaDownload
 {
 	EphyDownload parent;
 	MozillaDownloadPrivate *priv;
 };
 
-struct MozillaDownloadClass
+struct _MozillaDownloadClass
 {
 	EphyDownloadClass parent_class;
 };
