@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2000-2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright © 2000-2004 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed.cpp,v 1.127 2006/05/10 18:07:00 chpe Exp $
+ *  $Id: mozilla-embed.cpp,v 1.131 2006/10/24 21:17:56 jframeau Exp $
  */
 
 #include "mozilla-config.h"
@@ -134,7 +134,7 @@ mozilla_embed_get_type (void)
 
         if (G_UNLIKELY (type == 0))
         {
-                static const GTypeInfo our_info =
+                const GTypeInfo our_info =
                 {
                         sizeof (MozillaEmbedClass),
                         NULL, /* base_init */
@@ -147,14 +147,14 @@ mozilla_embed_get_type (void)
                         (GInstanceInitFunc) mozilla_embed_init
                 };
 
-		static const GInterfaceInfo embed_info =
+		const GInterfaceInfo embed_info =
 		{
 			(GInterfaceInitFunc) ephy_embed_iface_init,
         		NULL,
         		NULL
      		};
 
-		static const GInterfaceInfo ephy_command_manager_info =
+		const GInterfaceInfo ephy_command_manager_info =
 		{
 			(GInterfaceInitFunc) ephy_command_manager_iface_init,
         		NULL,
@@ -324,6 +324,43 @@ impl_load_url (EphyEmbed *embed,
         gtk_moz_embed_load_url (GTK_MOZ_EMBED(embed), url);
 }
 
+static char * impl_get_location (EphyEmbed *embed, gboolean toplevel);
+
+static void
+impl_load (EphyEmbed *embed, 
+           const char *url,
+	   EphyEmbedLoadFlags flags,
+	   EphyEmbed *preview_embed)
+{
+	EphyBrowser *browser;
+
+	browser = MOZILLA_EMBED(embed)->priv->browser;
+	g_return_if_fail (browser != NULL);
+
+	nsCOMPtr<nsIURI> uri;
+	if (preview_embed != NULL)
+	{
+		EphyBrowser *pbrowser;
+
+		pbrowser = MOZILLA_EMBED(preview_embed)->priv->browser;
+		if (pbrowser != NULL)
+		{
+			pbrowser->GetDocumentURI (getter_AddRefs (uri));
+		}
+	}
+
+#ifdef HAVE_GECKO_1_8_1
+	if (flags & EPHY_EMBED_LOAD_FLAGS_ALLOW_THIRD_PARTY_FIXUP)
+	{
+		browser->LoadURI (url, nsIWebNavigation::LOAD_FLAGS_ALLOW_THIRD_PARTY_FIXUP, uri);	
+	}
+	else
+#endif /* HAVE_GECKO_1_8_1 */
+	{
+		browser->LoadURI (url, nsIWebNavigation::LOAD_FLAGS_NONE, uri);	
+	}
+}
+
 static void
 impl_stop_load (EphyEmbed *embed)
 {
@@ -1114,6 +1151,7 @@ static void
 ephy_embed_iface_init (EphyEmbedIface *iface)
 {
 	iface->load_url = impl_load_url; 
+	iface->load = impl_load; 
 	iface->stop_load = impl_stop_load;
 	iface->can_go_back = impl_can_go_back;
 	iface->can_go_forward =impl_can_go_forward;
