@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-file-helpers.c 6589 2006-09-13 11:49:01Z chpe $
+ *  $Id: ephy-file-helpers.c,v 1.51 2006/10/15 14:05:39 wbolster Exp $
  */
 
 #include "config.h"
@@ -1017,6 +1017,27 @@ ephy_file_launch_handler (const char *mime_type,
 	return ret;
 }
 
+gboolean
+ephy_file_browse_to (const char *parameter,
+		     guint32 user_time)
+{
+	GnomeVFSURI *uri, *parent_uri;
+	gboolean ret;
+
+	uri = gnome_vfs_uri_new (parameter);
+	parent_uri = gnome_vfs_uri_get_parent (uri);
+
+	/* TODO find a way to make nautilus scroll to the actual file */
+	ret = ephy_file_launch_handler ("x-directory/normal", 
+					gnome_vfs_uri_get_path (parent_uri), 
+					user_time);
+	
+	gnome_vfs_uri_unref (uri);
+	gnome_vfs_uri_unref (parent_uri);
+
+	return ret;
+}
+
 struct _EphyFileMonitor
 {
 	GnomeVFSMonitorHandle *handle;
