@@ -1,5 +1,6 @@
 /*
- *  Copyright (C) 2000 Marco Pesenti Gritti
+ *  Copyright © 2000, 2003 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,69 +15,39 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-langs.h,v 1.12 2006/09/13 11:34:19 chpe Exp $
  */
 
 #ifndef EPHY_LANGS_H
 #define EPHY_LANGS_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <glib.h>
 
 G_BEGIN_DECLS
 
-/* language groups */
-typedef enum
-{
-	LG_ARABIC,
-	LG_BALTIC,
-	LG_CENTRAL_EUROPEAN,
-	LG_CHINESE,
-	LG_CYRILLIC,
-	LG_GREEK,
-	LG_HEBREW,
-	LG_INDIAN,
-	LG_JAPANESE, 
-	LG_KOREAN,
-	LG_TURKISH,
-	LG_UNICODE,
-	LG_VIETNAMESE,
-	LG_WESTERN,
-	LG_OTHER,
-	LG_ALL
-} LanguageGroup;
+#define ISO_639_DOMAIN	"iso_639"
+#define ISO_3166_DOMAIN	"iso_3166"
 
 typedef struct
 {
-	gchar *title;
-	gchar *key;
-	LanguageGroup group;
-} LanguageGroupInfo;
+	char *title;
+	char *code;
+} EphyFontsLanguageInfo;
 
-typedef struct
-{
-	gchar *title;
-	gchar *key;
-	gchar *encoding;
-	LanguageGroup group;
-} EncodingInfo;
+const EphyFontsLanguageInfo *ephy_font_languages	 (void);
 
-/* language encoding groups */
-typedef struct
-{
-	gchar *title;
-	gchar* code;
-} FontsLanguageInfo;
+guint			     ephy_font_n_languages	 (void);
 
-void	language_group_info_free	(LanguageGroupInfo *info);
+void			     ephy_langs_append_languages (GArray *array);
 
-void	encoding_info_free		(EncodingInfo *info);
+void			     ephy_langs_sanitise	 (GArray *array);
 
-guint				ephy_langs_get_n_font_languages	(void);
+char			   **ephy_langs_get_languages	 (void);
 
-const FontsLanguageInfo *	ephy_langs_get_font_languages	(void);
+GHashTable		    *ephy_langs_iso_639_table	 (void);
+
+GHashTable		    *ephy_langs_iso_3166_table   (void);
 
 G_END_DECLS
 
