@@ -1,6 +1,6 @@
 /* 
- *  Copyright (C) 2003 Crispin Flowerday <gnome@flowerday.cx>
- *  Copyright (C) 2005, 2006 Christian Persch
+ *  Copyright © 2003 Crispin Flowerday <gnome@flowerday.cx>
+ *  Copyright © 2005, 2006 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-password-dialog.c,v 1.1 2006/06/22 12:37:00 chpe Exp $
+ *  $Id: ephy-password-dialog.c,v 1.3 2006/09/13 11:34:19 chpe Exp $
  */
 
 #ifndef DONT_HAVE_CONFIG_H
@@ -76,6 +76,7 @@ struct _EphyPasswordDialogPrivate
 #endif
 	EphyPasswordDialogFlags flags;
 	guint checks : 5;
+	guint track_capslock : 1;
 };
 
 enum
@@ -239,6 +240,7 @@ entry_activate_cb (GtkWidget *entry,
 		if (entry == priv->entry[i]) break;
 	g_assert (i < N_ENTRIES);
 
+	++i;
 	for ( ; i < N_ENTRIES; ++i)
 		if (priv->entry[i] != NULL &&
 		    GTK_WIDGET_IS_SENSITIVE (priv->entry[i])) break;
@@ -454,6 +456,16 @@ ephy_password_dialog_constructor (GType type,
 		priv->checks |= CHECK_PWD_MATCH;
 	}
 
+	if (priv->flags & (EPHY_PASSWORD_DIALOG_FLAGS_SHOW_PASSWORD |
+			   EPHY_PASSWORD_DIALOG_FLAGS_SHOW_NEW_PASSWORD))
+	{
+		priv->track_capslock = TRUE;
+//		gtk_table_attach (table, widget,
+//				  1, 2, row, row + 1,
+//				  GTK_FILL | GTK_EXPAND, GTK_FILL, 0, 0);
+
+	}
+
 	/* Password quality meter */
 	/* TODO: We need a better password quality meter */
 	if (priv->flags & EPHY_PASSWORD_DIALOG_FLAGS_SHOW_NEW_PASSWORD &&
@@ -488,6 +500,8 @@ ephy_password_dialog_constructor (GType type,
 
 		priv->remember_button[2] = gtk_radio_button_new_with_mnemonic (group, _("Save password in _keyring"));
 		gtk_box_pack_start (GTK_BOX (rbox), priv->remember_button[2], FALSE, FALSE, 0);
+
+		gtk_widget_set_no_show_all (rbox, !gnome_keyring_is_available ());
 	}
 
 	gtk_dialog_add_button (dialog, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
@@ -705,3 +719,10 @@ ephy_password_dialog_get_new_password (EphyPasswordDialog *dialog)
 
 	return gtk_entry_get_text (GTK_ENTRY (priv->entry[NEW_PASSWORD_ENTRY]));
 }
+
+void
+ephy_password_dialog_fill (EphyPasswordDialog *dialog,
+			   GList *attributes_list)
+{
+	
+}
