@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-zoom.h,v 1.3 2003/11/19 19:19:52 chpe Exp $
+ *  $Id: ephy-zoom.h,v 1.5 2006/09/13 11:34:19 chpe Exp $
  */
 
 #ifndef EPHY_ZOOM_H
@@ -55,9 +55,10 @@ static const guint n_zoom_levels = G_N_ELEMENTS (zoom_levels);
 #define ZOOM_IN		(-1.0)
 #define ZOOM_OUT	(-2.0)
 
-guint	ephy_zoom_get_zoom_level_index	 (float level);
+int	ephy_zoom_get_zoom_level_index	 (float level);
 
-float	ephy_zoom_get_changed_zoom_level (float level, gint steps);
+float	ephy_zoom_get_changed_zoom_level (float level,
+					  int steps);
 
 float	ephy_zoom_get_nearest_zoom_level (float level);
 
