@@ -1,5 +1,5 @@
 /* 
- *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
+ *  Copyright © 2002 Jorn Baayen <jorn@nl.linux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-view.c,v 1.66 2006/07/10 20:44:03 chpe Exp $
+ *  $Id: ephy-node-view.c,v 1.68 2006/09/13 11:34:20 chpe Exp $
  */
 
 #include "config.h"
@@ -112,7 +112,7 @@ ephy_node_view_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyNodeViewClass),
 			NULL,
