@@ -1,9 +1,7 @@
 /* 
- * Nautilus
- *
- * Copyright (C) 2000 Eazel, Inc.
- * Copyright (C) 2002-2004 Marco Pesenti Gritti
- * Copyright (C) 2004 Christian Persch
+ * Copyright © 2000 Eazel, Inc.
+ * Copyright © 2002-2004 Marco Pesenti Gritti
+ * Copyright © 2004, 2006 Christian Persch
  *
  * Nautilus is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,9 +21,7 @@
  *
  * Ephy port by Marco Pesenti Gritti <marco@it.gnome.org>
  * 
- * This is the spinner (for busy feedback) for the location bar
- *
- * $Id: ephy-spinner.c,v 1.39 2005/10/29 14:21:24 chpe Exp $
+ * $Id: ephy-spinner.c,v 1.46 2006/10/17 20:32:46 chpe Exp $
  */
 
 #ifndef COMPILING_TESTSPINNER
@@ -68,34 +64,39 @@ struct _EphySpinnerCache
 
 #define EPHY_SPINNER_CACHE_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_SPINNER_CACHE, EphySpinnerCachePrivate))
 
-typedef struct
-{
-	GtkIconSize size;
-	int width;
-	int height;
-	GdkPixbuf *quiescent_pixbuf;
-	GList *images;
-} EphySpinnerImages;
-
-typedef struct
-{
-	GdkScreen *screen;
-	GtkIconTheme *icon_theme;
-	EphySpinnerImages *originals;
-	/* List of EphySpinnerImages scaled to different sizes */
-	GList *images;
-} EphySpinnerCacheData;
-
 struct _EphySpinnerCachePrivate
 {
 	/* Hash table of GdkScreen -> EphySpinnerCacheData */
 	GHashTable *hash;
 };
 
+typedef struct
+{
+	guint ref_count;
+	GtkIconSize size;
+	int width;
+	int height;
+	GdkPixbuf *quiescent_pixbuf;
+	GdkPixbuf **animation_pixbufs;
+	guint n_animation_pixbufs;
+} EphySpinnerImages;
+
+#define LAST_ICON_SIZE			GTK_ICON_SIZE_DIALOG + 1
+#define SPINNER_ICON_NAME		"gnome-spinner"
+#define SPINNER_REST_ICON_NAME		"gnome-spinner-rest"
+#define EPHY_SPINNER_IMAGES_INVALID	((EphySpinnerImages *) 0x1)
+
+typedef struct
+{
+	GdkScreen *screen;
+	GtkIconTheme *icon_theme;
+	EphySpinnerImages *images[LAST_ICON_SIZE];
+} EphySpinnerCacheData;
+
 static void ephy_spinner_cache_class_init (EphySpinnerCacheClass *klass);
 static void ephy_spinner_cache_init	  (EphySpinnerCache *cache);
 
-static GObjectClass *cache_parent_class = NULL;
+static GObjectClass *ephy_spinner_cache_parent_class;
 
 static GType
 ephy_spinner_cache_get_type (void)
@@ -104,7 +105,7 @@ ephy_spinner_cache_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphySpinnerCacheClass),
 			NULL,
@@ -125,44 +126,60 @@ ephy_spinner_cache_get_type (void)
 	return type;
 }
 
-static void
-ephy_spinner_images_free (EphySpinnerImages *images)
+static EphySpinnerImages *
+ephy_spinner_images_ref (EphySpinnerImages *images)
 {
-	if (images != NULL)
+	g_return_val_if_fail (images != NULL, NULL);
+
+	images->ref_count++;
+
+	return images;
+}
+
+static void
+ephy_spinner_images_unref (EphySpinnerImages *images)
+{
+	g_return_if_fail (images != NULL);
+
+	images->ref_count--;
+	if (images->ref_count == 0)
 	{
-		g_list_foreach (images->images, (GFunc) g_object_unref, NULL);
+		guint i;
+
+		LOG ("Freeing spinner images %p for size %d", images, images->size);
+
+		for (i = 0; i < images->n_animation_pixbufs; ++i)
+		{
+			g_object_unref (images->animation_pixbufs[i]);
+		}
+		g_free (images->animation_pixbufs);
+
 		g_object_unref (images->quiescent_pixbuf);
 
 		g_free (images);
 	}
 }
 
-static EphySpinnerImages *
-ephy_spinner_images_copy (EphySpinnerImages *images)
-{
-	EphySpinnerImages *copy = g_new (EphySpinnerImages, 1);
-
-	copy->size = images->size;
-	copy->width = images->width;
-	copy->height = images->height;
-
-	copy->quiescent_pixbuf = g_object_ref (images->quiescent_pixbuf);
-	copy->images = g_list_copy (images->images);
-	g_list_foreach (copy->images, (GFunc) g_object_ref, NULL);
-
-	return copy;
-}
-
 static void
 ephy_spinner_cache_data_unload (EphySpinnerCacheData *data)
 {
+	GtkIconSize size;
+	EphySpinnerImages *images;
+
 	g_return_if_fail (data != NULL);
 
 	LOG ("EphySpinnerDataCache unload for screen %p", data->screen);
 
-	g_list_foreach (data->images, (GFunc) ephy_spinner_images_free, NULL);
-	data->images = NULL;
-	data->originals = NULL;
+	for (size = GTK_ICON_SIZE_INVALID; size < LAST_ICON_SIZE; ++size)
+	{
+		images = data->images[size];
+		data->images[size] = NULL;
+
+		if (images != NULL && images != EPHY_SPINNER_IMAGES_INVALID)
+		{
+			ephy_spinner_images_unref (images);
+		}
+	}
 }
 
 static GdkPixbuf *
@@ -187,60 +204,109 @@ extract_frame (GdkPixbuf *grid_pixbuf,
 	return pixbuf;
 }
 
-static void
-ephy_spinner_cache_data_load (EphySpinnerCacheData *data)
+static GdkPixbuf *
+scale_to_size (GdkPixbuf *pixbuf,
+	       int dw,
+	       int dh)
+{
+	GdkPixbuf *result;
+	int pw, ph;
+
+	g_return_val_if_fail (pixbuf != NULL, NULL);
+
+	pw = gdk_pixbuf_get_width (pixbuf);
+	ph = gdk_pixbuf_get_height (pixbuf);
+
+	if (pw != dw || ph != dh)
+	{
+		result = gdk_pixbuf_scale_simple (pixbuf, dw, dh,
+						  GDK_INTERP_BILINEAR);
+		g_object_unref (pixbuf);
+		return result;
+	}
+
+	return pixbuf;
+}
+
+static EphySpinnerImages *
+ephy_spinner_images_load (GdkScreen *screen,
+			  GtkIconTheme *icon_theme,
+			  GtkIconSize icon_size)
 {
 	EphySpinnerImages *images;
+	GdkPixbuf *rest_pixbuf = NULL;
 	GdkPixbuf *icon_pixbuf, *pixbuf;
-	GtkIconInfo *icon_info;
-	int grid_width, grid_height, x, y, size, h, w;
+	GtkIconInfo *icon_info = NULL;
+	int grid_width, grid_height, x, y, requested_size, size, isw, ish, n;
 	const char *icon;
+	GSList *list = NULL, *l;
 
-	g_return_if_fail (data != NULL);
-
-	LOG ("EphySpinnerCacheData loading for screen %p", data->screen);
-
-	ephy_spinner_cache_data_unload (data);
+	LOG ("EphySpinnerCacheData loading for screen %p at size %d", screen, icon_size);
 
 	START_PROFILER ("loading spinner animation")
 
-	/* Load the animation */
-	icon_info = gtk_icon_theme_lookup_icon (data->icon_theme,
-						"gnome-spinner", -1, 0);
+	if (!gtk_icon_size_lookup_for_settings (gtk_settings_get_for_screen (screen),
+						icon_size, &isw, &ish)) goto loser;
+
+	requested_size = MAX (ish, isw);
+
+	/* Load the rest icon */
+	icon_info = gtk_icon_theme_lookup_icon (icon_theme,
+						SPINNER_REST_ICON_NAME,
+						requested_size, 0);
 	if (icon_info == NULL)
 	{
-		STOP_PROFILER ("loading spinner animation")
-
-		g_warning ("Throbber animation not found\n");
-		return;
+		g_warning ("Throbber rest icon not found");
+		goto loser;
 	}
 
 	size = gtk_icon_info_get_base_size (icon_info);
 	icon = gtk_icon_info_get_filename (icon_info);
-	g_return_if_fail (icon != NULL);
+	if (icon == NULL) goto loser;
+
+	rest_pixbuf = gdk_pixbuf_new_from_file (icon, NULL);
+	gtk_icon_info_free (icon_info);
+	icon_info = NULL;
+
+	if (rest_pixbuf == NULL)
+	{
+		g_warning ("Could not load spinner rest icon");
+		goto loser;
+	}
+
+	if (size > requested_size)
+	{
+		rest_pixbuf = scale_to_size (rest_pixbuf, isw, ish);
+	}
+
+	/* Load the animation */
+	icon_info = gtk_icon_theme_lookup_icon (icon_theme,
+						SPINNER_ICON_NAME,
+					        requested_size, 0);
+	if (icon_info == NULL)
+	{
+		g_warning ("Throbber animation not found");
+		goto loser;
+	}
+
+	size = gtk_icon_info_get_base_size (icon_info);
+	icon = gtk_icon_info_get_filename (icon_info);
+	if (icon == NULL) goto loser;
 
 	icon_pixbuf = gdk_pixbuf_new_from_file (icon, NULL);
+	gtk_icon_info_free (icon_info);
+	icon_info = NULL;
+
 	if (icon_pixbuf == NULL)
 	{
-		STOP_PROFILER ("loading spinner animation")
-
-		g_warning ("Could not load the spinner file\n");
-		gtk_icon_info_free (icon_info);
-		return;
+		g_warning ("Could not load the spinner file");
+		goto loser;
 	}
 
 	grid_width = gdk_pixbuf_get_width (icon_pixbuf);
 	grid_height = gdk_pixbuf_get_height (icon_pixbuf);
 
-	images = g_new (EphySpinnerImages, 1);
-	data->images = g_list_prepend (NULL, images);
-	data->originals = images;
-
-	images->size = GTK_ICON_SIZE_INVALID;
-	images->width = images->height = size;
-	images->images = NULL;
-	images->quiescent_pixbuf = NULL;
-
+	n = 0;
 	for (y = 0; y < grid_height; y += size)
 	{
 		for (x = 0; x < grid_width ; x += size)
@@ -249,55 +315,66 @@ ephy_spinner_cache_data_load (EphySpinnerCacheData *data)
 
 			if (pixbuf)
 			{
-				images->images =
-					g_list_prepend (images->images, pixbuf);
+				list = g_slist_prepend (list, pixbuf);
+				++n;
 			}
 			else
 			{
-				g_warning ("Cannot extract frame from the grid\n");
+				g_warning ("Cannot extract frame (%d, %d) from the grid\n", x, y);
 			}
 		}
 	}
-	images->images = g_list_reverse (images->images);
 
-	gtk_icon_info_free (icon_info);
 	g_object_unref (icon_pixbuf);
 
-	/* Load the rest icon */
-	icon_info = gtk_icon_theme_lookup_icon (data->icon_theme,
-						"gnome-spinner-rest", -1, 0);
-	if (icon_info == NULL)
-	{
-		STOP_PROFILER ("loading spinner animation")
+	if (list == NULL) goto loser;
+	g_assert (n > 0);
 
-		g_warning ("Throbber rest icon not found\n");
-		return;
+	if (size > requested_size)
+	{
+		for (l = list; l != NULL; l = l->next)
+		{
+			l->data = scale_to_size (l->data, isw, ish);
+		}
 	}
 
-	size = gtk_icon_info_get_base_size (icon_info);
-	icon = gtk_icon_info_get_filename (icon_info);
-	g_return_if_fail (icon != NULL);
+	/* Now we've successfully got all the data */
+	images = g_new (EphySpinnerImages, 1);
+	images->ref_count = 1;
 
-	icon_pixbuf = gdk_pixbuf_new_from_file (icon, NULL);
-	gtk_icon_info_free (icon_info);
+	images->size = icon_size;
+	images->width = images->height = requested_size;
+	images->quiescent_pixbuf = rest_pixbuf;
 
-	if (icon_pixbuf == NULL)
+	images->n_animation_pixbufs = n;
+	images->animation_pixbufs = g_new (GdkPixbuf *, n);
+
+	for (l = list; l != NULL; l = l->next)
 	{
-		STOP_PROFILER ("loading spinner animation")
-
-		g_warning ("Could not load spinner rest icon\n");
-		ephy_spinner_images_free (images);
-		return;
+		images->animation_pixbufs[--n] = l->data;
 	}
+	g_assert (n == 0);
 
-	images->quiescent_pixbuf = icon_pixbuf;
-
-	w = gdk_pixbuf_get_width (icon_pixbuf);
-	h = gdk_pixbuf_get_height (icon_pixbuf);
-	images->width = MAX (images->width, w);
-	images->height = MAX (images->height, h);
+	g_slist_free (list);
 
 	STOP_PROFILER ("loading spinner animation")
+
+	return images;
+
+loser:
+	if (icon_info)
+	{
+		gtk_icon_info_free (icon_info);
+	}
+	if (rest_pixbuf)
+	{
+		g_object_unref (rest_pixbuf);
+	}
+	g_slist_foreach (list, (GFunc) g_object_unref, NULL);
+
+	STOP_PROFILER ("loading spinner animation")
+
+	return NULL;
 }
 
 static EphySpinnerCacheData *
@@ -310,11 +387,9 @@ ephy_spinner_cache_data_new (GdkScreen *screen)
 	data->screen = screen;
 	data->icon_theme = gtk_icon_theme_get_for_screen (screen);
 	g_signal_connect_swapped (data->icon_theme, "changed",
-				  G_CALLBACK (ephy_spinner_cache_data_load),
+				  G_CALLBACK (ephy_spinner_cache_data_unload),
 				  data);
 
-	ephy_spinner_cache_data_load (data);
-
 	return data;
 }
 
@@ -326,121 +401,66 @@ ephy_spinner_cache_data_free (EphySpinnerCacheData *data)
 
 	g_signal_handlers_disconnect_by_func
 		(data->icon_theme,
-		 G_CALLBACK (ephy_spinner_cache_data_load), data);
+		 G_CALLBACK (ephy_spinner_cache_data_unload), data);
 
 	ephy_spinner_cache_data_unload (data);
 
 	g_free (data);
 }
 
-static int
-compare_size (gconstpointer images_ptr,
-	      gconstpointer size_ptr)
-{
-	const EphySpinnerImages *images = (const EphySpinnerImages *) images_ptr;
-	GtkIconSize size = GPOINTER_TO_INT (size_ptr);
-
-	if (images->size == size)
-	{
-		return 0;
-	}
-
-	return -1;
-}
-
-static GdkPixbuf *
-scale_to_size (GdkPixbuf *pixbuf,
-	       int dw,
-	       int dh)
-{
-	GdkPixbuf *result;
-	int pw, ph;
-
-	pw = gdk_pixbuf_get_width (pixbuf);
-	ph = gdk_pixbuf_get_height (pixbuf);
-
-	if (pw != dw || ph != dh)
-	{
-		result = gdk_pixbuf_scale_simple (pixbuf, dw, dh,
-						  GDK_INTERP_BILINEAR);
-	}
-	else
-	{
-		result = g_object_ref (pixbuf);
-	}
-
-	return result;
-}
-
 static EphySpinnerImages *
 ephy_spinner_cache_get_images (EphySpinnerCache *cache,
 			       GdkScreen *screen,
-			       GtkIconSize size)
+			       GtkIconSize icon_size)
 {
 	EphySpinnerCachePrivate *priv = cache->priv;
 	EphySpinnerCacheData *data;
 	EphySpinnerImages *images;
-	GtkSettings *settings;
-	GdkPixbuf *pixbuf, *scaled_pixbuf;
-	GList *element, *l;
-	int h, w;
 
-	LOG ("Getting animation images at size %d for screen %p", size, screen);
+	LOG ("Getting animation images for screen %p at size %d", screen, icon_size);
+
+	g_return_val_if_fail (icon_size >= 0 && icon_size < LAST_ICON_SIZE, NULL);
+
+	/* Backward compat: "invalid" meant "native" size which doesn't exist anymore */
+	if (icon_size == GTK_ICON_SIZE_INVALID)
+	{
+		icon_size = GTK_ICON_SIZE_DIALOG;
+	}
 
 	data = g_hash_table_lookup (priv->hash, screen);
 	if (data == NULL)
 	{
 		data = ephy_spinner_cache_data_new (screen);
+		/* FIXME: think about what happens when the screen's display is closed later on */
 		g_hash_table_insert (priv->hash, screen, data);
 	}
 
-	if (data->images == NULL || data->originals == NULL)
+	images = data->images[icon_size];
+	if (images == EPHY_SPINNER_IMAGES_INVALID)
 	{
 		/* Load failed, but don't try endlessly again! */
 		return NULL;
 	}
 
-	element = g_list_find_custom (data->images,
-				      GINT_TO_POINTER (size),
-				      (GCompareFunc) compare_size);
-	if (element != NULL)
+	if (images != NULL)
 	{
-		return ephy_spinner_images_copy ((EphySpinnerImages *) element->data);
+		/* Return cached data */
+		return ephy_spinner_images_ref (images);
 	}
 
-	settings = gtk_settings_get_for_screen (screen);
-	if (!gtk_icon_size_lookup_for_settings (settings, size, &w, &h))
+	images = ephy_spinner_images_load (screen, data->icon_theme, icon_size);
+
+	if (images == NULL)
 	{
-		g_warning ("Failed to look up icon size\n");
+		/* Mark as failed-to-load */
+		data->images[icon_size] = EPHY_SPINNER_IMAGES_INVALID;
+
 		return NULL;
 	}
 
-	images = g_new (EphySpinnerImages, 1);
-	images->size = size;
-	images->width = w;
-	images->height = h;
-	images->images = NULL;
+	data->images[icon_size] = images;
 
-	START_PROFILER ("scaling spinner animation")
-
-	for (l = data->originals->images; l != NULL; l = l->next)
-	{
-		pixbuf = (GdkPixbuf *) l->data;
-		scaled_pixbuf = scale_to_size (pixbuf, w, h);
-
-		images->images = g_list_prepend (images->images, scaled_pixbuf);
-	}
-	images->images = g_list_reverse (images->images);
-
-	images->quiescent_pixbuf =
-		scale_to_size (data->originals->quiescent_pixbuf, w, h);
-
-	/* store in cache */
-	data->images = g_list_prepend (data->images, images);
-
-	STOP_PROFILER ("scaling spinner animation")
-
-	return ephy_spinner_images_copy (images);
+	return ephy_spinner_images_ref (images);
 }
 
 static void
@@ -463,11 +483,11 @@ ephy_spinner_cache_finalize (GObject *object)
 	EphySpinnerCache *cache = EPHY_SPINNER_CACHE (object); 
 	EphySpinnerCachePrivate *priv = cache->priv;
 
-	LOG ("EphySpinnerCache finalising");
-
 	g_hash_table_destroy (priv->hash);
 
-	G_OBJECT_CLASS (cache_parent_class)->finalize (object);
+	LOG ("EphySpinnerCache finalised");
+
+	G_OBJECT_CLASS (ephy_spinner_cache_parent_class)->finalize (object);
 }
 
 static void
@@ -475,7 +495,7 @@ ephy_spinner_cache_class_init (EphySpinnerCacheClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	cache_parent_class = g_type_class_peek_parent (klass);
+	ephy_spinner_cache_parent_class = g_type_class_peek_parent (klass);
 
 	object_class->finalize = ephy_spinner_cache_finalize;
 
@@ -498,10 +518,8 @@ ephy_spinner_cache_ref (void)
 
 		return spinner_cache;
 	}
-	else
-	{
-		return g_object_ref (spinner_cache);
-	}
+		
+	return g_object_ref (spinner_cache);
 }
 
 /* Spinner implementation */
@@ -516,16 +534,17 @@ struct _EphySpinnerDetails
 	EphySpinnerCache *cache;
 	GtkIconSize size;
 	EphySpinnerImages *images;
-	GList *current_image;
+	guint current_image;
 	guint timeout;
 	guint timer_task;
 	guint spinning : 1;
+	guint need_load : 1;
 };
 
 static void ephy_spinner_class_init (EphySpinnerClass *class);
 static void ephy_spinner_init	    (EphySpinner *spinner);
 
-static GObjectClass *parent_class = NULL;
+static GObjectClass *parent_class;
 
 GType
 ephy_spinner_get_type (void)
@@ -534,7 +553,7 @@ ephy_spinner_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphySpinnerClass),
 			NULL, /* base_init */
@@ -547,7 +566,7 @@ ephy_spinner_get_type (void)
 			(GInstanceInitFunc) ephy_spinner_init
 		};
 
-		type = g_type_register_static (GTK_TYPE_EVENT_BOX,
+		type = g_type_register_static (GTK_TYPE_WIDGET,
 					       "EphySpinner",
 					       &our_info, 0);
 	}
@@ -560,7 +579,7 @@ ephy_spinner_load_images (EphySpinner *spinner)
 {
 	EphySpinnerDetails *details = spinner->details;
 
-	if (details->images == NULL)
+	if (details->need_load)
 	{
 		START_PROFILER ("ephy_spinner_load_images")
 
@@ -570,12 +589,10 @@ ephy_spinner_load_images (EphySpinner *spinner)
 				 gtk_widget_get_screen (GTK_WIDGET (spinner)),
 				 details->size);
 
-		if (details->images != NULL)
-		{
-			details->current_image = details->images->images;
-		}
-
 		STOP_PROFILER ("ephy_spinner_load_images")
+
+		details->current_image = 0;
+		details->need_load = FALSE;
 	}
 
 	return details->images != NULL;
@@ -584,9 +601,16 @@ ephy_spinner_load_images (EphySpinner *spinner)
 static void
 ephy_spinner_unload_images (EphySpinner *spinner)
 {
-	ephy_spinner_images_free (spinner->details->images);
-	spinner->details->images = NULL;
-	spinner->details->current_image = NULL;
+	EphySpinnerDetails *details = spinner->details;
+
+	if (details->images != NULL)
+	{
+		ephy_spinner_images_unref (details->images);
+		details->images = NULL;
+	}
+
+	details->current_image = 0;
+	details->need_load = TRUE;
 }
 
 static void
@@ -600,43 +624,17 @@ icon_theme_changed_cb (GtkIconTheme *icon_theme,
 static void
 ephy_spinner_init (EphySpinner *spinner)
 {
-	EphySpinnerDetails *details = spinner->details;
-	GtkWidget *widget = GTK_WIDGET (spinner);
-
-	gtk_widget_set_events (widget,
-			       gtk_widget_get_events (widget)
-			       | GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
-			       | GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK);
+	EphySpinnerDetails *details;
 
 	details = spinner->details = EPHY_SPINNER_GET_PRIVATE (spinner);
 
+	GTK_WIDGET_SET_FLAGS (GTK_WIDGET (spinner), GTK_NO_WINDOW);
+
 	details->cache = ephy_spinner_cache_ref ();
-	details->size = GTK_ICON_SIZE_INVALID;
+	details->size = GTK_ICON_SIZE_DIALOG;
 	details->spinning = FALSE;
 	details->timeout = SPINNER_TIMEOUT;
-}
-
-static GdkPixbuf *
-select_spinner_image (EphySpinner *spinner)
-{
-	EphySpinnerDetails *details = spinner->details;
-	EphySpinnerImages *images = details->images;
-
-	g_return_val_if_fail (images != NULL, NULL);
-
-	if (spinner->details->timer_task == 0)
-	{
-		if (images->quiescent_pixbuf != NULL)
-		{
-			return g_object_ref (details->images->quiescent_pixbuf);
-		}
-
-		return NULL;
-	}
-
-	g_return_val_if_fail (details->current_image != NULL, NULL);
-
-	return g_object_ref (details->current_image->data);
+	details->need_load = TRUE;
 }
 
 static int
@@ -644,6 +642,8 @@ ephy_spinner_expose (GtkWidget *widget,
 		     GdkEventExpose *event)
 {
 	EphySpinner *spinner = EPHY_SPINNER (widget);
+	EphySpinnerDetails *details = spinner->details;
+	EphySpinnerImages *images;
 	GdkPixbuf *pixbuf;
 	GdkGC *gc;
 	int x_offset, y_offset, width, height;
@@ -651,15 +651,34 @@ ephy_spinner_expose (GtkWidget *widget,
 
 	if (!GTK_WIDGET_DRAWABLE (spinner))
 	{
-		return TRUE;
+		return FALSE;
 	}
 
-	if (!ephy_spinner_load_images (spinner))
+	if (details->need_load &&
+	    !ephy_spinner_load_images (spinner))
 	{
-		return TRUE;
+		return FALSE;
+	}
+
+	images = details->images;
+	if (images == NULL)
+	{
+		return FALSE;
+	}
+
+	if (details->spinning &&
+	    images->n_animation_pixbufs > 0)
+	{
+		g_assert (details->current_image >= 0 &&
+			  details->current_image < images->n_animation_pixbufs);
+
+		pixbuf = images->animation_pixbufs[details->current_image];
+	}
+	else
+	{
+		pixbuf = images->quiescent_pixbuf;
 	}
 
-	pixbuf = select_spinner_image (spinner);
 	if (pixbuf == NULL)
 	{
 		return FALSE;
@@ -679,7 +698,6 @@ ephy_spinner_expose (GtkWidget *widget,
 
 	if (!gdk_rectangle_intersect (&event->area, &pix_area, &dest))
 	{
-		g_object_unref (pixbuf);
 		return FALSE;
 	}
 
@@ -692,8 +710,6 @@ ephy_spinner_expose (GtkWidget *widget,
 			 GDK_RGB_DITHER_MAX, 0, 0);
 	g_object_unref (gc);
 
-	g_object_unref (pixbuf);
-
 	return FALSE;
 }
 
@@ -701,9 +717,6 @@ static gboolean
 bump_spinner_frame_cb (EphySpinner *spinner)
 {
 	EphySpinnerDetails *details = spinner->details;
-	GList *frame;
-
-	if (!GTK_WIDGET_DRAWABLE (spinner)) return TRUE;
 
 	/* This can happen when we've unloaded the images on a theme
 	 * change, but haven't been in the queued size request yet.
@@ -711,19 +724,11 @@ bump_spinner_frame_cb (EphySpinner *spinner)
 	 */
 	if (details->images == NULL) return TRUE;
 
-	frame = details->current_image;
-	g_assert (frame != NULL);
-
-	if (frame->next != NULL)
+	details->current_image++;
+	if (details->current_image >= details->images->n_animation_pixbufs)
 	{
-		frame = frame->next;
+		details->current_image = 0;
 	}
-	else
-	{
-		frame = g_list_first (frame);
-	}
-
-	details->current_image = frame;
 
 	gtk_widget_queue_draw (GTK_WIDGET (spinner));
 
@@ -748,11 +753,7 @@ ephy_spinner_start (EphySpinner *spinner)
 	    details->timer_task == 0 &&
 	    ephy_spinner_load_images (spinner))
 	{
-		if (details->images != NULL)
-		{
-			/* reset to first frame */
-			details->current_image = details->images->images;
-		}
+		details->current_image = 0;
 
 		details->timer_task =
 			g_timeout_add (details->timeout,
@@ -764,10 +765,12 @@ ephy_spinner_start (EphySpinner *spinner)
 static void
 ephy_spinner_remove_update_callback (EphySpinner *spinner)
 {
-	if (spinner->details->timer_task != 0)
+	EphySpinnerDetails *details = spinner->details;
+
+	if (details->timer_task != 0)
 	{
-		g_source_remove (spinner->details->timer_task);
-		spinner->details->timer_task = 0;
+		g_source_remove (details->timer_task);
+		details->timer_task = 0;
 	}
 }
 
@@ -784,7 +787,7 @@ ephy_spinner_stop (EphySpinner *spinner)
 
 	details->spinning = FALSE;
 
-	if (spinner->details->timer_task != 0)
+	if (details->timer_task != 0)
 	{
 		ephy_spinner_remove_update_callback (spinner);
 
@@ -800,13 +803,17 @@ ephy_spinner_stop (EphySpinner *spinner)
  * @spinner: a #EphySpinner
  * @size: the size of type %GtkIconSize
  *
- * Set the size of the spinner. Use %GTK_ICON_SIZE_INVALID to use the
- * native size of the icons.
+ * Set the size of the spinner.
  **/
 void
 ephy_spinner_set_size (EphySpinner *spinner,
 		       GtkIconSize size)
 {
+	if (size == GTK_ICON_SIZE_INVALID)
+	{
+		size = GTK_ICON_SIZE_DIALOG;
+	}
+
 	if (size != spinner->details->size)
 	{
 		ephy_spinner_unload_images (spinner);
@@ -850,25 +857,29 @@ ephy_spinner_size_request (GtkWidget *widget,
 			   GtkRequisition *requisition)
 {
 	EphySpinner *spinner = EPHY_SPINNER (widget);
+	EphySpinnerDetails *details = spinner->details;
 
-	if (!ephy_spinner_load_images (spinner))
+	if ((details->need_load &&
+	     !ephy_spinner_load_images (spinner)) ||
+            details->images == NULL)
 	{
 		requisition->width = requisition->height = 0;
 		gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (widget),
-						   spinner->details->size,
+						   details->size,
 						   &requisition->width,
 					           &requisition->height);
 		return;
 	}
 
-	requisition->width = spinner->details->images->width;
-	requisition->height = spinner->details->images->height;
+	requisition->width = details->images->width;
+	requisition->height = details->images->height;
 
+	/* FIXME fix this hack */
 	/* allocate some extra margin so we don't butt up against toolbar edges */
-	if (spinner->details->size != GTK_ICON_SIZE_MENU)
+	if (details->size != GTK_ICON_SIZE_MENU)
 	{
-		requisition->width += 4;
-		requisition->height += 4;
+		requisition->width += 2;
+		requisition->height += 2;
 	}
 }
 
@@ -990,7 +1001,5 @@ ephy_spinner_class_init (EphySpinnerClass *class)
 GtkWidget *
 ephy_spinner_new (void)
 {
-	return GTK_WIDGET (g_object_new (EPHY_TYPE_SPINNER,
-					 "visible-window", FALSE,
-					 NULL));
+	return GTK_WIDGET (g_object_new (EPHY_TYPE_SPINNER, NULL));
 }
