@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright © 2003, 2004 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmark-action.h,v 1.10 2006/01/16 22:30:39 paharvey Exp $
+ *  $Id: ephy-bookmark-action.h,v 1.13 2006/09/13 11:34:24 chpe Exp $
  */
 
 #ifndef EPHY_BOOKMARK_ACTION_H
@@ -55,22 +55,21 @@ struct _EphyBookmarkActionClass
 };
 
 
-GType       ephy_bookmark_action_get_type (void);
+GType		ephy_bookmark_action_get_type		(void);
 
-char *      ephy_bookmark_action_name     (EphyNode *node);
+GtkAction      *ephy_bookmark_action_new		(EphyNode *node,
+							 const char *name);
 
-GtkAction * ephy_bookmark_action_new      (EphyNode *node, char *name);
+void		ephy_bookmark_action_set_bookmark	(EphyBookmarkAction *action,
+		 					 EphyNode *node);
 
+EphyNode       *ephy_bookmark_action_get_bookmark	(EphyBookmarkAction *action);
 
-void        ephy_bookmark_action_set_bookmark (EphyBookmarkAction *action, EphyNode *node);
+void		ephy_bookmark_action_updated		(EphyBookmarkAction *action);
 
-EphyNode *  ephy_bookmark_action_get_bookmark (EphyBookmarkAction *action);
-
-void        ephy_bookmark_action_updated      (EphyBookmarkAction *action);
-
-void        ephy_bookmark_action_activate     (EphyBookmarkAction *action,
-					       GtkWidget *widget,
-					       EphyLinkFlags flags);
+void		ephy_bookmark_action_activate		(EphyBookmarkAction *action,
+							 GtkWidget *widget,
+							 EphyLinkFlags flags);
 
 G_END_DECLS
 
