@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks-export.c 6857 2007-01-28 20:06:27Z chpe $
+ *  $Id: ephy-bookmarks-export.c,v 1.22 2006/09/13 11:34:24 chpe Exp $
  */
 
 #include "config.h"
@@ -35,33 +35,6 @@
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
-static inline xmlChar *
-sanitise_string (const xmlChar *string)
-{
-	xmlChar *copy, *p;
-
-	if (!string)
-		return xmlStrdup ((const xmlChar *) "");
-
-	/* http://www.w3.org/TR/REC-xml/#sec-well-formed :
-	   Character Range
-	   [2]     Char       ::=          #x9 | #xA | #xD | [#x20-#xD7FF] |
-	   [#xE000-#xFFFD] | [#x10000-#x10FFFF]
-	   any Unicode character, excluding the surrogate blocks, FFFE, and FFFF.
-	*/
-
-	copy = xmlStrdup (string);
-	for (p = copy; *p; p++)
-	{
-		xmlChar c = *p;
-		if (G_UNLIKELY (c < 0x20 && c != 0xd && c != 0xa && c != 0x9)) {
-			*p = 0x20;
-		}
-	}
-
-	return copy;
-}
-
 static int
 write_topics_list (EphyNode *topics,
 		   EphyNode *bmk,
@@ -94,20 +67,16 @@ write_topics_list (EphyNode *topics,
 	{
 		EphyNode *node = l->data;
 		const char *name;
-		xmlChar *safeName;
 
 		name = ephy_node_get_property_string
 			(node, EPHY_NODE_KEYWORD_PROP_NAME);
-		safeName = sanitise_string ((const xmlChar *) name);
 
 		ret = xmlTextWriterWriteElementNS
 			(writer, 
 			 (xmlChar *) "dc",
 			 (xmlChar *) "subject",
 			 NULL,
-			 safeName);
-		xmlFree (safeName);
-
+			 (xmlChar *) name);
 		if (ret < 0) break;
 	}
 
@@ -125,7 +94,6 @@ write_rdf (EphyBookmarks *bookmarks,
 	GPtrArray *children;
 	char *file_uri;
 	int i, ret;
-	xmlChar *safeString;
 #ifdef ENABLE_ZEROCONF
 	EphyNode *local;
 #endif
@@ -167,18 +135,15 @@ write_rdf (EphyBookmarks *bookmarks,
 	ret = xmlTextWriterStartElement (writer, (xmlChar *) "channel");
 	if (ret < 0) goto out;
 
-	/* FIXME: sanitise file_uri? */
+	/* FIXME is this UTF-8 ? */
 	file_uri = gnome_vfs_get_uri_from_local_path (filename);
-	safeString = sanitise_string ((const xmlChar *) file_uri);
-	g_free (file_uri);
-
 	ret = xmlTextWriterWriteAttributeNS
 		(writer,
 		 (xmlChar *) "rdf",
 		 (xmlChar *) "about",
 		 NULL,
-		 safeString);
-	xmlFree (safeString);
+		 (xmlChar *) file_uri);
+	g_free (file_uri);
 	if (ret < 0) goto out;
 
 	ret = xmlTextWriterWriteElement 
@@ -217,7 +182,6 @@ write_rdf (EphyBookmarks *bookmarks,
 		const char *url;
 		char *link = NULL;
 		gboolean smart_url;
-		xmlChar *safeLink;
 
 		kid = g_ptr_array_index (children, i);
 
@@ -226,6 +190,13 @@ write_rdf (EphyBookmarks *bookmarks,
 		if (ephy_node_has_child (local, kid)) continue;
 #endif
 
+		ret = xmlTextWriterStartElementNS
+			(writer,
+			 (xmlChar *) "rdf",
+			 (xmlChar *) "li",
+			 NULL);
+		if (ret < 0) break;
+
 		smart_url = ephy_node_has_child (smart_bmks, kid);
 		url = ephy_node_get_property_string
 			(kid, EPHY_NODE_BMK_PROP_LOCATION);
@@ -246,23 +217,13 @@ write_rdf (EphyBookmarks *bookmarks,
 			}
 		}
 
-		safeLink = sanitise_string (link ? (const xmlChar *) link : (const xmlChar *) url);
-		g_free (link);
-
-		ret = xmlTextWriterStartElementNS
-			(writer,
-			 (xmlChar *) "rdf",
-			 (xmlChar *) "li",
-			 NULL);
-		if (ret < 0) break;
-
 		ret = xmlTextWriterWriteAttributeNS
 			(writer,
 			 (xmlChar *) "rdf",
 			 (xmlChar *) "resource",
 			 NULL,
-			 safeLink);
-		xmlFree (safeLink);
+			 (xmlChar *) (link ? link : url));
+		g_free (link);
 		if (ret < 0) break;
 
 		ret = xmlTextWriterEndElement (writer); /* rdf:li */
@@ -286,7 +247,6 @@ write_rdf (EphyBookmarks *bookmarks,
 		const char *url, *title;
 		char *link = NULL;
 		gboolean smart_url;
-		xmlChar *safeLink, *safeTitle;
 
 		kid = g_ptr_array_index (children, i);
 
@@ -326,48 +286,34 @@ write_rdf (EphyBookmarks *bookmarks,
 		ret = xmlTextWriterStartElement (writer, (xmlChar *) "item");
 		if (ret < 0) break;
 
-		safeLink = sanitise_string ((const xmlChar *) link);
-		g_free (link);
-
 		ret = xmlTextWriterWriteAttributeNS
 			(writer,
 			 (xmlChar *) "rdf",
 			 (xmlChar *) "about",
 			 NULL,
-			 safeLink);
-		if (ret < 0)
-		{
-			xmlFree (safeLink);
-			break;
-		}
+			 (xmlChar *) link);
+		if (ret < 0) break;
 
-		safeTitle = sanitise_string ((const xmlChar *) title);
 		ret = xmlTextWriterWriteElement
 			(writer,
 			 (xmlChar *) "title",
-			 safeTitle);
-		xmlFree (safeTitle);
+			 (xmlChar *) title);
 		if (ret < 0) break;
 
 		ret = xmlTextWriterWriteElement
 			(writer,
 			 (xmlChar *) "link",
-			 safeLink);
-		xmlFree (safeLink);
+			 (xmlChar *) link);
 		if (ret < 0) break;
 
 		if (smart_url)
 		{
-			xmlChar *safeSmartLink;
-
-			safeSmartLink = sanitise_string ((const xmlChar *) url);
 			ret = xmlTextWriterWriteElementNS
 				(writer,
 				 (xmlChar *) "ephy",
 				 (xmlChar *) "smartlink",
 				 NULL,
-				 safeSmartLink);
-			xmlFree (safeSmartLink);
+				 (xmlChar *) url);
 			if (ret < 0) break;
 		}
 
@@ -375,6 +321,8 @@ write_rdf (EphyBookmarks *bookmarks,
 		if (ret < 0) break;
 
 		ret = xmlTextWriterEndElement (writer); /* item */
+
+		g_free (link);
 	}
 	if (ret < 0) goto out;
 
