@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2004, 2005 Jean-François Rameau
- *  Copyright (C) 2006 Christian Persch
+ *  Copyright © 2004, 2005 Jean-François Rameau
+ *  Copyright © 2006 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-dbus.c,v 1.16 2006/04/03 11:56:01 chpe Exp $
+ *  $Id: ephy-dbus.c,v 1.19 2006/10/18 09:08:04 wbolster Exp $
  */
 
 #include "config.h"
@@ -301,16 +301,6 @@ ephy_dbus_connect_to_session_bus (EphyDbus *ephy_dbus,
 	return TRUE;
 }
 
-static void
-ephy_dbus_disconnect_bus (DBusGConnection *bus)
-{
-	if (bus != NULL) {
-		dbus_connection_close
-			(dbus_g_connection_get_connection (bus));
-		dbus_g_connection_unref (bus);
-	}
-}
-
 /* Public methods */
 
 static void
@@ -337,7 +327,7 @@ ephy_dbus_shutdown (EphyDbus *dbus)
 		dbus_connection_remove_filter
 			(dbus_g_connection_get_connection (priv->session_bus),
 			 session_filter_func, dbus);
-		ephy_dbus_disconnect_bus (priv->session_bus);
+		dbus_g_connection_unref (priv->session_bus);
 		priv->session_bus = NULL;
 	}
 
@@ -346,7 +336,7 @@ ephy_dbus_shutdown (EphyDbus *dbus)
 		dbus_connection_remove_filter
 			(dbus_g_connection_get_connection (priv->system_bus),
 			 system_filter_func, dbus);
-		ephy_dbus_disconnect_bus (priv->system_bus);
+		dbus_g_connection_unref (priv->system_bus);
 		priv->system_bus = NULL;
 	}
 }
@@ -455,7 +445,7 @@ ephy_dbus_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyDbusClass),
 			NULL, /* base_init */
