@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2000, 2001, 2002, 2003, 2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004, 2005 Christian Persch
+ *  Copyright © 2000, 2001, 2002, 2003, 2004 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004, 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-lockdown.c,v 1.8 2005/10/21 16:15:09 philipl Exp $
+ *  $Id: ephy-lockdown.c,v 1.15 2006/09/24 19:59:37 jframeau Exp $
  */
 
 #include "config.h"
@@ -182,8 +182,6 @@ update_window (EphyWindow *window,
 	disabled = eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_SAVE_TO_DISK);
 	action = gtk_action_group_get_action (action_group, "FileSaveAs");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
-	action = gtk_action_group_get_action (action_group, "FileSave");
-	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
 	action = gtk_action_group_get_action (popups_action_group, "DownloadLink");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
 	action = gtk_action_group_get_action (popups_action_group, "DownloadLinkAs");
@@ -195,16 +193,14 @@ update_window (EphyWindow *window,
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled || !writable);
 
 	disabled = eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_TOOLBAR_EDITING);
-	action = gtk_action_group_get_action (action_group, "EditToolbar");
+	action = gtk_action_group_get_action (action_group, "ViewToolbarEditor");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
 
 	fullscreen = eel_gconf_get_boolean (CONF_LOCKDOWN_FULLSCREEN);
-	action = gtk_action_group_get_action (action_group, "FileNewWindow");
+	action = gtk_action_group_get_action (toolbar_action_group, "FileNewWindow");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, fullscreen);
 	action = gtk_action_group_get_action (action_group, "ViewFullscreen");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, fullscreen);
-	action = gtk_action_group_get_action (action_group, "TabsDetach");
-	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, fullscreen);
 
 	if (fullscreen)
 	{
@@ -235,16 +231,17 @@ ephy_lockdown_init (EphyLockdown *lockdown)
 
 	LOG ("EphyLockdown initialising");
 
-	/* lockdown pref notifiers */
 	for (i = 0; i < G_N_ELEMENTS (keys); i++)
 	{
 		priv->notifier_id[i] =eel_gconf_notification_add
 			(keys[i], (GConfClientNotifyFunc) notifier, lockdown);
 	}
-
 	/* We know that no windows are open yet,
-	 * so we don't need to do anything else here.
+	 * so we don't need to do notify here.
 	 */
+
+	eel_gconf_monitor_add ("/apps/epiphany/lockdown");
+	eel_gconf_monitor_add ("/desktop/gnome/lockdown");
 }
 
 static void
@@ -256,6 +253,9 @@ ephy_lockdown_finalize (GObject *object)
 
 	LOG ("EphyLockdown finalising");
 
+	eel_gconf_monitor_remove ("/apps/epiphany/lockdown");
+	eel_gconf_monitor_remove ("/desktop/gnome/lockdown");
+
 	for (i = 0; i < G_N_ELEMENTS (keys); i++)
 	{
 		eel_gconf_notification_remove (priv->notifier_id[i]);
@@ -316,7 +316,7 @@ ephy_lockdown_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyLockdownClass),
 			NULL, /* base_init */
@@ -328,7 +328,7 @@ ephy_lockdown_get_type (void)
 			0, /* n_preallocs */
 			(GInstanceInitFunc) ephy_lockdown_init
 		};
-		static const GInterfaceInfo extension_info =
+		const GInterfaceInfo extension_info =
 		{
 			(GInterfaceInitFunc) ephy_lockdown_iface_init,
 			NULL,
