@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2000-2004 Marco Pesenti Gritti
- *  Copyright (C) 2001, 2002 Jorn Baayen
- *  Copyright (C) 2003, 2004, 2005 Christian Persch
+ *  Copyright © 2000-2004 Marco Pesenti Gritti
+ *  Copyright © 2001, 2002 Jorn Baayen
+ *  Copyright © 2003, 2004, 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-toolbar.c,v 1.29 2006/01/30 22:13:07 paharvey Exp $
+ *  $Id: ephy-toolbar.c,v 1.34 2006/10/17 20:56:10 chpe Exp $
  */
 
 #include "config.h"
@@ -31,7 +31,7 @@
 #include "ephy-navigation-action.h"
 #include "ephy-topic-action.h"
 #include "ephy-zoom-action.h"
-#include "ephy-spinner.h"
+#include "ephy-spinner-tool-item.h"
 #include "ephy-dnd.h"
 #include "ephy-shell.h"
 #include "ephy-stock-icons.h"
@@ -71,8 +71,7 @@ struct _EphyToolbarPrivate
 	GtkActionGroup *action_group;
 	GtkAction *actions[LAST_ACTION];
 	GtkWidget *fixed_toolbar;
-	GtkWidget *spinner;
-	GtkToolItem *spinner_item;
+	EphySpinnerToolItem *spinner;
 	GtkToolItem *sep_item;
 	GtkToolItem *exit_button;
 	gulong set_focus_handler;
@@ -135,35 +134,7 @@ ephy_toolbar_update_spinner (EphyToolbar *toolbar)
 {
 	EphyToolbarPrivate *priv = toolbar->priv;
 
-	if (priv->spinning)
-	{
-		ephy_spinner_start (EPHY_SPINNER (priv->spinner));
-	}
-	else
-	{
-		ephy_spinner_stop (EPHY_SPINNER (priv->spinner));
-	}
-}
-
-static void
-fixed_toolbar_reconfigured_cb (GtkToolItem *item,
-			       EphySpinner *spinner)
-{
-	GtkToolbarStyle style;
-	GtkIconSize size;
-
-	style = gtk_tool_item_get_toolbar_style (item);
-
-	if (style == GTK_TOOLBAR_BOTH)
-	{
-		size = GTK_ICON_SIZE_INVALID;
-	}
-	else
-	{
-		size = GTK_ICON_SIZE_LARGE_TOOLBAR;
-	}
-
-	ephy_spinner_set_size (spinner, size);
+	ephy_spinner_tool_item_set_spinning (priv->spinner, priv->spinning);
 }
 
 static void 
@@ -359,6 +330,29 @@ ephy_toolbar_set_window (EphyToolbar *toolbar,
 				  G_CALLBACK (ephy_link_open), toolbar);
 	gtk_action_group_add_action_with_accel (priv->action_group, action, "<alt>Home");
 	g_object_unref (action);
+
+	action = g_object_new (EPHY_TYPE_HOME_ACTION,
+			       "name", "FileNewTab",
+			       "label", _("New _Tab"),
+			       "stock_id", STOCK_NEW_TAB,
+			       "tooltip", _("Open a new tab"),
+			       NULL);
+	g_signal_connect_swapped (action, "open-link",
+				  G_CALLBACK (ephy_link_open), toolbar);
+	gtk_action_group_add_action_with_accel (priv->action_group, action, "<control>T");
+	g_object_unref (action);
+
+	action = g_object_new (EPHY_TYPE_HOME_ACTION,
+			       "name", "FileNewWindow",
+			       "label", _("_New Window"),
+			       "stock_id", STOCK_NEW_WINDOW,
+			       "tooltip", _("Open a new window"),
+			       NULL);
+	g_signal_connect_swapped (action, "open-link",
+				  G_CALLBACK (ephy_link_open), toolbar);
+	gtk_action_group_add_action_with_accel (priv->action_group, action, "<control>N");
+	g_object_unref (action);
+
 }
 
 /* public functions */
@@ -566,15 +560,9 @@ ephy_toolbar_constructor (GType type,
 	gtoolbar = GTK_TOOLBAR (priv->fixed_toolbar);
 	gtk_toolbar_set_show_arrow (gtoolbar, FALSE);
 
-	priv->spinner = ephy_spinner_new ();
-	gtk_widget_show (priv->spinner);
-
-	priv->spinner_item = gtk_tool_item_new ();
-	g_signal_connect (priv->spinner_item, "toolbar-reconfigured",
-			  G_CALLBACK (fixed_toolbar_reconfigured_cb), priv->spinner);
-	gtk_container_add (GTK_CONTAINER (priv->spinner_item), priv->spinner);
-	gtk_toolbar_insert (gtoolbar, priv->spinner_item, -1);
-	gtk_widget_show (GTK_WIDGET (priv->spinner_item));
+	priv->spinner = ephy_spinner_tool_item_new ();
+	gtk_toolbar_insert (gtoolbar, GTK_TOOL_ITEM (priv->spinner), -1);
+	gtk_widget_show (GTK_WIDGET (priv->spinner));
 
 	priv->sep_item = gtk_separator_tool_item_new ();
 	gtk_toolbar_insert (gtoolbar, priv->sep_item, -1);
@@ -703,7 +691,7 @@ ephy_toolbar_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyToolbarClass),
 			NULL, /* base_init */
@@ -715,7 +703,7 @@ ephy_toolbar_get_type (void)
 			0, /* n_preallocs */
 			(GInstanceInitFunc) ephy_toolbar_init
 		};
-		static const GInterfaceInfo link_info = 
+		const GInterfaceInfo link_info = 
 		{
 			NULL,
 			NULL,
@@ -736,9 +724,19 @@ ephy_toolbar_get_type (void)
 EphyToolbar *
 ephy_toolbar_new (EphyWindow *window)
 {
-	return EPHY_TOOLBAR (g_object_new (EPHY_TYPE_TOOLBAR,
-					   "window", window,
-					   "ui-manager", ephy_window_get_ui_manager (window),
-					   "visibility-path", "/menubar/ViewMenu/ViewTogglesGroup/ToolbarMenu",
-					   NULL));
+	EggEditableToolbar *etoolbar;
+	
+	etoolbar = EGG_EDITABLE_TOOLBAR 
+	  (g_object_new (EPHY_TYPE_TOOLBAR,
+			 "window", window,
+			 "ui-manager", ephy_window_get_ui_manager (window),
+			 "popup-path", "/ToolbarPopup",
+			 NULL));
+	
+	egg_editable_toolbar_add_visibility 
+	  (etoolbar, "/menubar/ViewMenu/ViewTogglesGroup/ToolbarMenu/ViewToolbarsGroup");
+	egg_editable_toolbar_add_visibility 
+	  (etoolbar, "/ToolbarPopup/ViewToolbarsGroup");
+
+	return EPHY_TOOLBAR (etoolbar);
 }
