@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: popup-commands.c,v 1.57 2006/01/16 23:51:41 chpe Exp $
+ *  $Id: popup-commands.c,v 1.64 2006/10/17 22:50:40 wbolster Exp $
  */
 
 #include "config.h"
@@ -51,7 +51,7 @@ popup_cmd_link_in_new_window (GtkAction *action,
 	event = ephy_window_get_context_event (window);
 	g_return_if_fail (event != NULL);
 
-	ephy_embed_event_get_property (event, "link", &value);
+	value = ephy_embed_event_get_property (event, "link");
 
 	ephy_shell_new_tab (ephy_shell, NULL, tab,
 			    g_value_get_string (value),
@@ -72,7 +72,7 @@ popup_cmd_link_in_new_tab (GtkAction *action,
 	event = ephy_window_get_context_event (window);
 	g_return_if_fail (event != NULL);
 
-	ephy_embed_event_get_property (event, "link", &value);
+	value = ephy_embed_event_get_property (event, "link");
 
 	ephy_shell_new_tab (ephy_shell, window, tab,
 			    g_value_get_string (value),
@@ -98,11 +98,11 @@ popup_cmd_bookmark_link (GtkAction *action,
 	event = ephy_window_get_context_event (window);
 	g_return_if_fail (event != NULL);
 
-	ephy_embed_event_get_property (event, "link_is_smart", &link_is_smart);
-	ephy_embed_event_get_property (event, "link", &link);
-	ephy_embed_event_get_property (event, "link_title", &link_title);
-	ephy_embed_event_get_property (event, "link_rel", &link_rel);
-	ephy_embed_event_get_property (event, "linktext", &linktext);
+	link_is_smart = ephy_embed_event_get_property (event, "link_is_smart");
+	link = ephy_embed_event_get_property (event, "link");
+	link_title = ephy_embed_event_get_property (event, "link_title");
+	link_rel = ephy_embed_event_get_property (event, "link_rel");
+	linktext = ephy_embed_event_get_property (event, "linktext");
 
 	location = g_value_get_string (link);
 	g_return_if_fail (location);
@@ -127,7 +127,7 @@ popup_cmd_bookmark_link (GtkAction *action,
 		location = rel;
 	}
 
-	ephy_bookmarks_ui_add_bookmark (GTK_WIDGET (window), location, title);
+	ephy_bookmarks_ui_add_bookmark (GTK_WINDOW (window), location, title);
 }
 
 static void
@@ -155,18 +155,36 @@ popup_cmd_copy_link_address (GtkAction *action,
 
 	if (context & EPHY_EMBED_CONTEXT_EMAIL_LINK)
 	{
-		ephy_embed_event_get_property (event, "email", &value);
+		value = ephy_embed_event_get_property (event, "email");
 		address = g_value_get_string (value);
 		popup_cmd_copy_to_clipboard (window, address);
 	}
 	else if (context & EPHY_EMBED_CONTEXT_LINK)
 	{
-		ephy_embed_event_get_property (event, "link", &value);
+		value = ephy_embed_event_get_property (event, "link");
 		address = g_value_get_string (value);
 		popup_cmd_copy_to_clipboard (window, address);
 	}
 }
 
+static void
+save_property_url_completed_cb (EphyEmbedPersist *persist)
+{
+	if (!(ephy_embed_persist_get_flags (persist) & 
+				EPHY_EMBED_PERSIST_ASK_DESTINATION))
+	{
+		const char *dest;
+		guint32 user_time;
+
+		user_time = ephy_embed_persist_get_user_time (persist);
+		dest = ephy_embed_persist_get_dest (persist);
+		g_return_if_fail (dest != NULL);
+
+		eel_gconf_get_string (CONF_STATE_DOWNLOAD_DIR);
+		ephy_file_browse_to (dest, user_time);
+	}
+}
+
 static void
 save_property_url (GtkAction *action,
 		   const char *title,
@@ -186,7 +204,7 @@ save_property_url (GtkAction *action,
 	embed = ephy_window_get_active_embed (window);
 	g_return_if_fail (embed != NULL);
 
-	ephy_embed_event_get_property (event, property, &value);
+	value = ephy_embed_event_get_property (event, property);
 	location = g_value_get_string (value);
 
 	persist = EPHY_EMBED_PERSIST
@@ -201,6 +219,9 @@ save_property_url (GtkAction *action,
 		(persist, CONF_STATE_SAVE_DIR);
 	ephy_embed_persist_set_source (persist, location);
 
+	g_signal_connect (persist, "completed",
+			  G_CALLBACK (save_property_url_completed_cb), NULL);
+
 	ephy_embed_persist_save (persist);
 
 	g_object_unref (G_OBJECT(persist));
@@ -219,7 +240,7 @@ popup_cmd_open_link (GtkAction *action,
 	g_return_if_fail (embed != NULL);
 
 	event = ephy_window_get_context_event (window);
-	ephy_embed_event_get_property (event, "link", &value);
+	value = ephy_embed_event_get_property (event, "link");
 	location = g_value_get_string (value);
 
 	ephy_embed_load_url (embed, location);
@@ -254,25 +275,16 @@ static void
 background_download_completed (EphyEmbedPersist *persist)
 {
 	const char *bg;
-	char *type;
 	guint32 user_time;
 
 	user_time = ephy_embed_persist_get_user_time (persist);
 
 	bg = ephy_embed_persist_get_dest (persist);
-	eel_gconf_set_string (CONF_DESKTOP_BG_PICTURE, bg);
-
-	type = eel_gconf_get_string (CONF_DESKTOP_BG_TYPE);
-	if (type == NULL || strcmp (type, "none") == 0)
-	{
-		eel_gconf_set_string (CONF_DESKTOP_BG_TYPE, "wallpaper");
-	}
-	g_free (type);
 
 	g_object_unref (persist);
 
 	/* open the "Background Properties" capplet */
-	ephy_file_launch_desktop_file ("background.desktop", user_time);
+	ephy_file_launch_desktop_file ("background.desktop", bg, user_time);
 }
 
 void
@@ -292,7 +304,7 @@ popup_cmd_set_image_as_background (GtkAction *action,
 	embed = ephy_window_get_active_embed (window);
 	g_return_if_fail (embed != NULL);
 
-	ephy_embed_event_get_property (event, "image", &value);
+	value = ephy_embed_event_get_property (event, "image");
 	location = g_value_get_string (value);
 
 	persist = EPHY_EMBED_PERSIST
@@ -327,7 +339,7 @@ popup_cmd_copy_image_location (GtkAction *action,
 	const GValue *value;
 
 	event = ephy_window_get_context_event (window);
-	ephy_embed_event_get_property (event, "image", &value);
+	value = ephy_embed_event_get_property (event, "image");
 	location = g_value_get_string (value);
 	popup_cmd_copy_to_clipboard (window, location);
 }
@@ -435,7 +447,7 @@ popup_cmd_open_image (GtkAction *action,
 	embed = ephy_window_get_active_embed (window);
 	g_return_if_fail (embed != NULL);
 
-	ephy_embed_event_get_property (event, "image", &value);
+	value = ephy_embed_event_get_property (event, "image");
 	address = g_value_get_string (value);
 
 	scheme = gnome_vfs_get_uri_scheme (address);
